# This script locates the libmodplug
# Based on the FindThor.cmake module
# ========================================
#
# Output
# ------
#
# This script defines the following variables:
# - ModPlug_LIBRARY_DEBUG:   Name of the debug library (set to ModPlug_LIBRARY_RELEASE if no debug version is found)
# - ModPlug_LIBRARY_RELEASE: Name of the release library (set to ModPlug_LIBRARY_DEBUG if no release version is found)
# - ModPlug_LIBRARY:		  Name of the library to link to (includes both debug and release names if necessary)
# - ModPlug_INCLUDE_DIR:	  The path where libmodplug headers are located (the directory containing the modplug.h file)
# - ModPlug_FOUND:		      Is TRUE if at least one of the debug or release library is found
#
# Usage example:
# 
#   find_package(ModPlug 2 REQUIRED)
#   include_directories(${ModPlug_INCLUDE_DIR})
#   target_link_libraries(MyProject ${ModPlug_LIBRARY})


# Deduce the libraries suffix from the options
set(FINDModPlug_LIB_SUFFIX "")
if(SFML_STATIC_LIBRARIES)
	set(FINDModPlug_LIB_SUFFIX "-s")
endif()

# Find the SFML include directory
find_path(ModPlug_INCLUDE_DIR modplug.h
		  PATH_SUFFIXES include
		  PATHS
		  ${ModPlug_ROOT}
		  $ENV{ModPlug_ROOT}
		  /usr/local/
		  /usr/
		  /sw          # Fink
		  /opt/local/  # DarwinPorts
		  /opt/csw/    # Blastwave
		  /opt/)

# Find the requested modules
set(ModPlug_FOUND TRUE) # will be set to false if one of the required modules is not found
set(FINDModPlug_LIB_PATHS
	${ModPlug_ROOT}
	$ENV{ModPlug_ROOT}
	/usr/local
	/usr
	/sw
	/opt/local
	/opt/csw
	/opt)

# Debug library
find_library(ModPlug_LIBRARY_DEBUG
			 NAMES libmodplug${FINDModPlug_LIB_SUFFIX}-d
			 PATH_SUFFIXES lib64 lib
			 PATHS ${FINDModPlug_LIB_PATHS})

# Release library
find_library(ModPlug_LIBRARY_RELEASE
			 NAMES libmodplug${FINDModPlug_LIB_SUFFIX}
			 PATH_SUFFIXES lib64 lib
			 PATHS ${FINDModPlug_LIB_PATHS})

if(ModPlug_LIBRARY_DEBUG OR ModPlug_LIBRARY_RELEASE)
	# Library found
	set(ModPlug_FOUND TRUE)

	# If both are found, set ModPlug_LIBRARY to contain both
	if(ModPlug_LIBRARY_DEBUG AND ModPlug_LIBRARY_RELEASE)
		set(ModPlug_LIBRARY debug	 ${ModPlug_LIBRARY_DEBUG}
						 optimized ${ModPlug_LIBRARY_RELEASE})
	endif()

	# If only one debug/release variant is found, set the other to be equal to the found one
	if(ModPlug_LIBRARY_DEBUG AND NOT ModPlug_LIBRARY_RELEASE)
		# debug and not release
		set(ModPlug_LIBRARY_RELEASE ${ModPlug_LIBRARY_DEBUG})
		set(ModPlug_LIBRARY		 ${ModPlug_LIBRARY_DEBUG})
	endif()
	if(ModPlug_LIBRARY_RELEASE AND NOT ModPlug_LIBRARY_DEBUG)
		# release and not debug
		set(ModPlug_LIBRARY_DEBUG ${ModPlug_LIBRARY_RELEASE})
		set(ModPlug_LIBRARY	   ${ModPlug_LIBRARY_RELEASE})
	endif()
else()
	# Library not found
	set(ModPlug_FOUND FALSE)
	set(ModPlug_LIBRARY "")
	set(FINDModPlug_MISSING "${FINDModPlug_MISSING} ModPlug_LIBRARY")
endif()

# Mark variables as advanced
mark_as_advanced(ModPlug_INCLUDE_DIR
				 ModPlug_LIBRARY
				 ModPlug_LIBRARY_RELEASE
				 ModPlug_LIBRARY_DEBUG)

# Result
if(ModPlug_FOUND)
	# Success
	message("Found libmodplug: ${ModPlug_INCLUDE_DIR}")
else()
	# include directory or library not found
	set(FINDModPlug_ERROR "Could NOT find libmodplug (missing: ${FINDModPlug_MISSING})")

	if(ModPlug_FIND_REQUIRED)
		# Fatal error
		message(FATAL_ERROR ${FINDModPlug_ERROR})
	elseif(NOT ModPlug_FIND_QUIETLY)
		# Error, but continue
		message("${FINDModPlug_ERROR}")
	endif()
endif()
